@@ -126,7 +126,7 @@ namespace Oxygen
         {}
 
         //* event filter
-        bool eventFilter( QObject* object, QEvent* event )
+        bool eventFilter( QObject* object, QEvent* event ) override
         {
 
             if( event->type() == QEvent::MouseButtonRelease )
